@@ -3,12 +3,11 @@ package Math::Random::MT;
 use strict;
 use Carp;
 use DynaLoader;
-use Time::HiRes qw(gettimeofday); # standard in Perl >= 5.8
 use vars qw( @ISA $VERSION );
 
 my $gen = undef;
 @ISA = qw( DynaLoader );
-$VERSION = '1.13';
+$VERSION = '1.14';
 
 bootstrap Math::Random::MT $VERSION;
 
@@ -55,11 +54,11 @@ sub rand
 sub _rand_seed {
     my ($self) = @_;
 
-    # Seed rand with the same gettimeofday-based formula that is
-    # used in Perl, and return an integer between 0 and 2**32-1.
-
-    my ($s, $u) = gettimeofday;
-    CORE::srand(1000003*$s+3*$u);
+    # Get a seed at random through Perl's CORE::rand(). We do not call
+    # CORE::srand() to avoid altering the random numbers that other parts of
+    # the running script might be using. The seeds obtained by rapid calls to
+    # the _rand_seed() function are all different.
+    
     return int(CORE::rand(2**32));
 }
 
